==> libssh-docs-0.11.3-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/pages_1a.js <==
var searchData=
[
  ['read_20write_20on_20a_20file_20on_20the_20remote_20computer_0',['Performing an asynchronous read/write on a file on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'']]],
  ['reading_20a_20basic_20example_1',['Using the sftp aio API for reading (a basic example)',['../libssh_tutor_sftp_aio.html#sftp_aio_read',1,'']]],
  ['reading_20a_20file_20from_20the_20remote_20computer_2',['Reading a file from the remote computer',['../libssh_tutor_sftp.html#sftp_read',1,'']]],
  ['reading_20files_20and_20directories_3',['Reading files and directories',['../libssh_tutor_scp.html#scp_read',1,'']]],
  ['receiving_20full_20directory_20trees_20from_20the_20remote_20server_4',['Receiving full directory trees from the remote server',['../libssh_tutor_scp.html#scp_recursive_read',1,'']]],
  ['remote_20command_5',['remote command',['../libssh_tutor_command.html',1,'Chapter 4: Passing a remote command'],['../libssh_tutor_command.html#exec_remote',1,'Executing a remote command'],['../libssh_tutor_command.html#remote_command',1,'Passing a remote command']]],
  ['remote_20computer_6',['remote computer',['../libssh_tutor_shell.html#read_data',1,'Displaying the data sent by the remote computer'],['../libssh_tutor_sftp.html#sftp_aio',1,'Performing an asynchronous read/write on a file on the remote computer'],['../libssh_tutor_sftp.html#sftp_read',1,'Reading a file from the remote computer'],['../libssh_tutor_shell.html#write_data',1,'Sending user input to the remote computer'],['../libssh_tutor_sftp.html#sftp_write',1,'Writing to a file on the remote computer']]],
  ['remote_20data_7',['A more elaborate way to get the remote data',['../libssh_tutor_shell.html#select_loop',1,'']]],
  ['remote_20server_8',['remote server',['../libssh_tutor_scp.html#scp_recursive_write',1,'Copying full directory trees to the remote server'],['../libssh_tutor_scp.html#scp_recursive_read',1,'Receiving full directory trees from the remote server']]],
  ['remote_20shell_9',['remote shell',['../libssh_tutor_shell.html',1,'Chapter 3: Opening a remote shell'],['../libssh_tutor_shell.html#opening_shell',1,'Opening a remote shell']]],
  ['remote_20side_10',['Using graphical applications on the remote side',['../libssh_tutor_shell.html#x11',1,'']]],
  ['requisites_20openssl_203_200_208_11',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
  ['requisites_20openssl_203_200_20_3a_12',['Pre-requisites (OpenSSL &amp;lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
  ['reverse_20port_20forwarding_13',['Reverse port forwarding',['../libssh_tutor_forwarding.html#forwarding_reverse',1,'']]],
  ['reverse_20port_20forwarding_20with_20libssh_14',['Doing reverse port forwarding with libssh',['../libssh_tutor_forwarding.html#libssh_reverse',1,'']]]
];

==> libssh-docs-0.12.0-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/pages_1a.js <==
var searchData=
[
  ['read_20write_20on_20a_20file_20on_20the_20remote_20computer_0',['Performing an asynchronous read/write on a file on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'']]],
  ['reading_20a_20basic_20example_1',['Using the sftp aio API for reading (a basic example)',['../libssh_tutor_sftp_aio.html#sftp_aio_read',1,'']]],
  ['reading_20a_20file_20from_20the_20remote_20computer_2',['Reading a file from the remote computer',['../libssh_tutor_sftp.html#sftp_read',1,'']]],
  ['reading_20files_20and_20directories_3',['Reading files and directories',['../libssh_tutor_scp.html#scp_read',1,'']]],
  ['receiving_20full_20directory_20trees_20from_20the_20remote_20server_4',['Receiving full directory trees from the remote server',['../libssh_tutor_scp.html#scp_recursive_read',1,'']]],
  ['remote_20command_5',['remote command',['../libssh_tutor_command.html',1,'Chapter 4: Passing a remote command'],['../libssh_tutor_command.html#exec_remote',1,'Executing a remote command'],['../libssh_tutor_command.html#remote_command',1,'Passing a remote command']]],
  ['remote_20computer_6',['remote computer',['../libssh_tutor_shell.html#read_data',1,'Displaying the data sent by the remote computer'],['../libssh_tutor_sftp.html#sftp_aio',1,'Performing an asynchronous read/write on a file on the remote computer'],['../libssh_tutor_sftp.html#sftp_read',1,'Reading a file from the remote computer'],['../libssh_tutor_shell.html#write_data',1,'Sending user input to the remote computer'],['../libssh_tutor_sftp.html#sftp_write',1,'Writing to a file on the remote computer']]],
  ['remote_20data_7',['A more elaborate way to get the remote data',['../libssh_tutor_shell.html#select_loop',1,'']]],
  ['remote_20server_8',['remote server',['../libssh_tutor_scp.html#scp_recursive_write',1,'Copying full directory trees to the remote server'],['../libssh_tutor_scp.html#scp_recursive_read',1,'Receiving full directory trees from the remote server']]],
  ['remote_20shell_9',['remote shell',['../libssh_tutor_shell.html',1,'Chapter 3: Opening a remote shell'],['../libssh_tutor_shell.html#opening_shell',1,'Opening a remote shell']]],
  ['remote_20side_10',['Using graphical applications on the remote side',['../libssh_tutor_shell.html#x11',1,'']]],
  ['requisites_20openssl_203_200_208_11',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
  ['requisites_20openssl_203_200_20_3a_12',['Pre-requisites (OpenSSL &amp;lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
  ['resident_20key_20enumeration_13',['Resident Key Enumeration',['../libssh_tutor_fido2.html#fido2_resident',1,'']]],
  ['resident_20keys_14',['Resident Keys',['../libssh_tutor_fido2.html#fido2_resident_keys',1,'']]],
  ['reverse_20port_20forwarding_15',['Reverse port forwarding',['../libssh_tutor_forwarding.html#forwarding_reverse',1,'']]],
  ['reverse_20port_20forwarding_20with_20libssh_16',['Doing reverse port forwarding with libssh',['../libssh_tutor_forwarding.html#libssh_reverse',1,'']]]
];
